GenomicHilbertCurve-class provides following methods:GenomicHilbertCurve: constructor method;hc_points,GenomicHilbertCurve-method: add points;hc_segments,GenomicHilbertCurve-method: add lines;hc_rect,GenomicHilbertCurve-method: add rectangles;hc_polygon,GenomicHilbertCurve-method: add poygons;hc_text,GenomicHilbertCurve-method: add text;hc_layer,GenomicHilbertCurve-method: add layers undel "pixel" mode;hc_map,GenomicHilbertCurve-method: show the map of different categories on the curve. Works both for "normal" and "pixel" modeThe usage of above functions are almost same as those functions for the HilbertCurve-class
except that the second argument which specifies the intervals should be a GRanges object.
GenomicHilbertCurve-class is inherited from the HilbertCurve-class. Basically
the structure of this class is almost the same as the HilbertCurve-class but with several
additional slots added to facilitate visualizing genomic data.